[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# FactSet Private Company client library for Python

[![API Version](https://img.shields.io/badge/api-v1.0.0-blue)](https://developer.factset.com/api-catalog/factset-private-company-api)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.FactSetPrivateCompany/1.0.0)](https://pypi.org/project/fds.sdk.FactSetPrivateCompany/v/1.0.0)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

FactSet Private Company API encompasses Private Company Financials and includes some Private Company non-periodic data. Additional Private Company firmographics can be found in the FactSet Entity API. <p><b>Rate limit is set to 10 requests per second and 10 concurrent requests per user</b>.</p>


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- SDK version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.FactSetPrivateCompany==1.0.0
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.FactSetPrivateCompany==1.0.0
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.FactSetPrivateCompany
from fds.sdk.FactSetPrivateCompany.api import company_reports_api
from fds.sdk.FactSetPrivateCompany.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.FactSetPrivateCompany.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.FactSetPrivateCompany.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.FactSetPrivateCompany.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = company_reports_api.CompanyReportsApi(api_client)
    ids = ["0H3R4Y-E"] # [str] | The requested list of Factset Private Company identifiers in XXXXXX-E format <p>***ids limit** =  50 per request*</p> 
    statement_type = "BS" # str | The type of financial statement being requested
    currency = "USD" # str | Currency code for currency values. For a list of currency ISO codes, visit Online Assistant Page [OA1470](https://my.apps.factset.com/oa/pages/1470).  Giving input as \"DOC\" would give the values in reporting currency for the requested ids.  (optional) if omitted the server will use the default value of "LOCAL"
    number_annual_periods = 4 # int | The number of annual periods for the returned data which will be displayed in descending order from most recent annual period for the number of annual periods specified. </br>Within range of 1 to 100. If not specified default will be 4.       (optional) if omitted the server will use the default value of 4

    try:
        # Returns Private Company Financial Data
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.get_financials_report(ids, statement_type, currency=currency, number_annual_periods=number_annual_periods)

        pprint(api_response)
    except fds.sdk.FactSetPrivateCompany.ApiException as e:
        print("Exception when calling CompanyReportsApi->get_financials_report: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Returns Private Company Financial Data
    #     api_response, http_status_code, response_headers = api_instance.get_financials_report_with_http_info(ids, statement_type, currency=currency, number_annual_periods=number_annual_periods)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.FactSetPrivateCompany.ApiException as e:
    #     print("Exception when calling CompanyReportsApi->get_financials_report: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Returns Private Company Financial Data
    #     async_result = api_instance.get_financials_report_async(ids, statement_type, currency=currency, number_annual_periods=number_annual_periods)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.FactSetPrivateCompany.ApiException as e:
    #     print("Exception when calling CompanyReportsApi->get_financials_report: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Returns Private Company Financial Data
    #     async_result = api_instance.get_financials_report_with_http_info_async(ids, statement_type, currency=currency, number_annual_periods=number_annual_periods)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.FactSetPrivateCompany.ApiException as e:
    #     print("Exception when calling CompanyReportsApi->get_financials_report: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.FactSetPrivateCompany

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.FactSetPrivateCompany.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.FactSetPrivateCompany

configuration = fds.sdk.FactSetPrivateCompany.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.FactSetPrivateCompany

configuration = fds.sdk.FactSetPrivateCompany.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.FactSetPrivateCompany

configuration = fds.sdk.FactSetPrivateCompany.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/content/private-company/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CompanyReportsApi* | [**get_financials_report**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/CompanyReportsApi.md#get_financials_report) | **GET** /company-reports/financial-statement | Returns Private Company Financial Data
*CompanyReportsApi* | [**get_profile_report**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/CompanyReportsApi.md#get_profile_report) | **GET** /company-reports/profile | Returns Private Company Non-Periodic Data
*FinancialsApi* | [**get_financials**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/FinancialsApi.md#get_financials) | **GET** /financials | Returns Private Company Financial Data.
*FinancialsApi* | [**get_financials_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/FinancialsApi.md#get_financials_for_list) | **POST** /financials | Returns Private Company Financial Data.
*MetricsApi* | [**get_metrics**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/MetricsApi.md#get_metrics) | **GET** /metrics | Returns available private company metrics, and ratios.
*NonPeriodicApi* | [**get_non_periodic**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/NonPeriodicApi.md#get_non_periodic) | **GET** /non-periodic | Returns Private Company Reference Data.
*NonPeriodicApi* | [**get_non_periodic_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/NonPeriodicApi.md#get_non_periodic_for_list) | **POST** /non-periodic | Returns Private Company Reference Data.
*UniverseApi* | [**get_universe**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/UniverseApi.md#get_universe) | **GET** /universe | Returns Entity Candidates and Matches for a single name and attributes.
*UniverseApi* | [**get_universe_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/UniverseApi.md#get_universe_for_list) | **POST** /universe | Returns Entity Candidates and Matches for a requested list of up to 25 names and attributes.


## Documentation For Models

 - [EntityMatch](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/EntityMatch.md)
 - [EntityMatchRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/EntityMatchRequest.md)
 - [EntityMatchRequestBody](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/EntityMatchRequestBody.md)
 - [EntityMatchesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/EntityMatchesResponse.md)
 - [ErrorObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/ErrorObject.md)
 - [ErrorObjectLinks](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/ErrorObjectLinks.md)
 - [ErrorResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/ErrorResponse.md)
 - [FinancialStatements](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/FinancialStatements.md)
 - [FinancialStatementsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/FinancialStatementsResponse.md)
 - [Financials](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/Financials.md)
 - [FinancialsMetrics](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/FinancialsMetrics.md)
 - [FinancialsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/FinancialsRequest.md)
 - [FinancialsRequestBody](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/FinancialsRequestBody.md)
 - [FinancialsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/FinancialsResponse.md)
 - [Metric](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/Metric.md)
 - [MetricsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/MetricsResponse.md)
 - [NonPeriodic](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/NonPeriodic.md)
 - [NonPeriodicMetrics](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/NonPeriodicMetrics.md)
 - [NonPeriodicRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/NonPeriodicRequest.md)
 - [NonPeriodicRequestBody](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/NonPeriodicRequestBody.md)
 - [NonPeriodicResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/NonPeriodicResponse.md)
 - [NonPeriodicValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/NonPeriodicValue.md)
 - [PrivateMarketIds](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/PrivateMarketIds.md)
 - [Profile](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/Profile.md)
 - [ProfileResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/ProfileResponse.md)
 - [StatementItem](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrivateCompany/v1/docs/StatementItem.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.FactSetPrivateCompany.apis and fds.sdk.FactSetPrivateCompany.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.FactSetPrivateCompany.api.default_api import DefaultApi`
- `from fds.sdk.FactSetPrivateCompany.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.FactSetPrivateCompany
from fds.sdk.FactSetPrivateCompany.apis import *
from fds.sdk.FactSetPrivateCompany.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2025 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

